# ecom-candidate-matching

Find out more by reading: [project details](https://oneafricamedia.atlassian.net/wiki/spaces/dprod/pages/2365816872?atlOrigin=eyJpIjoiODRlNGYwYWU5YmEwNDQ5MmE0ZTllZjlkZDMyNzVlYzIiLCJwIjoiaiJ9)

## Getting started

```

# install packages
make install-dev

# run tests
make tests

# run autolinting before pushing to git
make autolint

# run cleanup for hanging objects,etc
make clean

```
